===============================
menugen
===============================

.. image:: https://img.shields.io/travis/iansmcf/menugen.svg
        :target: https://travis-ci.org/iansmcf/menugen

.. image:: https://img.shields.io/pypi/v/menugen.svg
        :target: https://pypi.python.org/pypi/menugen


Generates menus

* Free software: BSD license
* Documentation: https://menugen.readthedocs.org.

Features
--------

* TODO
